==> osam-2.4.9.tar.gz: example/lib/main.dart <==
import 'package:example/middleware.dart';
import 'package:example/presenter.dart';
import 'package:example/state/state.dart';
import 'package:flutter/material.dart';
import 'package:osam/osam.dart';
import 'package:osam/presentation/life_cycle_wrapper.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  final store = Store(AppState(), middleWares: [MyMiddleware()]);
//  await store.initPersist();
//  store.restoreState();
  runApp(MyApp(
    store: store,
  ));
}

enum EventType { increment, incrementValue }

class MyApp extends StatelessWidget {
  final Store<AppState> store;

  const MyApp({Key key, this.store}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: StoreProvider(
        child: MyHomePage(),
        store: store,
      ),
    );
  }
}

class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              'You have pushed the button this many times:',
            )
          ],
        ),
      ),
      floatingActionButton: PresenterProvider(
        key: ValueKey('counter'),
        presenter: ExamplePresenter(),
        child: Button(),
      ),
    );
  }
}

class Button extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final presenter = PresenterProvider.of<ExamplePresenter>(context);
    return FloatingActionButton(
      onPressed: () {
        presenter.increment();
      },
      child: StreamBuilder(
        initialData: presenter.initialData,
        stream: presenter.stream,
        builder: (ctx, AsyncSnapshot<int> snapshot) {
          return Text(snapshot.data.toString());
        },
      ),
    );
  }
}

==> osam-2.5.7.tar.gz: example/lib/main.dart <==
import 'package:example/middleware.dart';
import 'package:example/presenter.dart';
import 'package:example/state/state.dart';
import 'package:flutter/material.dart';
import 'package:osam/osam.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  final store = Store(AppState(), middleWares: [MyMiddleware()]);
  runApp(MyApp(
    store: store,
    key: GlobalKey(),
  ));
}

enum EventType { increment, incrementValue }

class MyApp extends StatelessWidget {
  final Store<AppState> store;

  const MyApp({Key key, this.store}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: StoreProvider(
        child: MyHomePage(),
        store: store,
      ),
    );
  }
}

class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              'You have pushed the button this many times:',
            ),
          ],
        ),
      ),
      floatingActionButton: PresenterProvider(
        key: ValueKey('counter'),
        presenter: ExamplePresenter(),
        child: Button(),
      ),
    );
  }
}

class Button extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final presenter = PresenterProvider.of<ExamplePresenter>(context);
    return Column(
      children: <Widget>[
        FloatingActionButton(
          onPressed: () {
            presenter.increment();
          },
          child: StreamBuilder(
            initialData: presenter.initialData,
            stream: presenter.stream,
            builder: (ctx, AsyncSnapshot<int> snapshot) {
              return Text(snapshot.data.toString());
            },
          ),
        ),
        FloatingActionButton(
          onPressed: () {
            presenter.increment2();
          },
          child: StreamBuilder(
            initialData: presenter.initialData,
            stream: presenter.stream,
            builder: (ctx, AsyncSnapshot<int> snapshot) {
              return Text(snapshot.data.toString());
            },
          ),
        ),
      ],
    );
  }
}
